CA05-Cl03
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Portal links |
clickAndWait | link=Añadir portal link |
type | id_name_es | Portal Link CA05-Cl03
select | id_category | label=Primary link
type | id_slug | portal-link-ca05-cl03
clickAndWait | _continue |
clickAndWait | link=Portal Links |
clickAndWait | link=Portal Link CA05-Cl03 |
verifySelectedLabel | id_category | Primary link
verifyNotSelectedLabel | id_category | Secondary link
select | id_category | label=Secondary link
clickAndWait | _save |
clickAndWait | link=Portal Link CA05-Cl03 |
verifyNotSelectedLabel | id_category | Primary link
verifySelectedLabel | id_category | Secondary link
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |